"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lisk_sdk_1 = require("lisk-sdk");
const constants_1 = require("./constants");
const schema_1 = require("./schema");
const reclaim_asset_1 = require("./transaction_assets/reclaim_asset");
class LegacyAccountModule extends lisk_sdk_1.BaseModule {
    constructor() {
        super(...arguments);
        this.name = 'legacyAccount';
        this.id = 1000;
        this.transactionAssets = [new reclaim_asset_1.ReclaimAsset()];
        this.actions = {
            getUnregisteredAccount: async (params) => {
                if (!(params === null || params === void 0 ? void 0 : params.publicKey) || typeof (params === null || params === void 0 ? void 0 : params.publicKey) !== 'string') {
                    throw new Error('Public key is either not provided or not a string');
                }
                const encodedUnregisteredAddresses = await this._dataAccess.getChainState(constants_1.CHAIN_STATE_UNREGISTERED_ADDRESSES);
                if (!encodedUnregisteredAddresses) {
                    throw new Error('Chain state does not contain any unregistered addresses');
                }
                const { unregisteredAddresses } = lisk_sdk_1.codec.decode(schema_1.unregisteredAddressesSchema, encodedUnregisteredAddresses);
                const legacyAddress = reclaim_asset_1.getLegacyBytes(Buffer.from(params.publicKey, 'hex'));
                const addressWithoutPublickey = unregisteredAddresses.find(a => a.address.equals(legacyAddress));
                return addressWithoutPublickey
                    ? {
                        address: addressWithoutPublickey.address.toString('hex'),
                        balance: addressWithoutPublickey.balance.toString(),
                    }
                    : undefined;
            },
        };
    }
    async afterGenesisBlockApply({ genesisBlock, reducerHandler, stateStore, }) {
        const { accounts } = genesisBlock.header.asset;
        const unregisteredAddresses = accounts.filter(account => account.address.length !== 20);
        const unregisteredAddressesWithBalance = await Promise.all(unregisteredAddresses.map(async ({ address }) => {
            const balance = await reducerHandler.invoke('token:getBalance', { address });
            return { address, balance };
        }));
        const encodedUnregisteredAddresses = lisk_sdk_1.codec.encode(schema_1.unregisteredAddressesSchema, {
            unregisteredAddresses: unregisteredAddressesWithBalance,
        });
        for (const { address } of unregisteredAddresses) {
            await stateStore.account.del(address);
        }
        stateStore.chain.set(constants_1.CHAIN_STATE_UNREGISTERED_ADDRESSES, encodedUnregisteredAddresses);
    }
}
exports.LegacyAccountModule = LegacyAccountModule;
//# sourceMappingURL=legacy_account_module.js.map